@@ -108,6 +108,7 @@ lme_model <- function(data,
       opt_control <- "optim"
       return(opt_control)
     }
+    return(opt_control)
   }
 
 
@@ -123,19 +124,19 @@ lme_model <- function(data,
     lmerCtr <- lme4::lmerControl(optimizer = opt_control)
 
     if (use_package == "lmerTest") {
-      model <- do.call(getfun("lmerTest::lmer"), list(
+      model <- lmerTest::lmer(
         formula = lmerformula,
         data = data,
         na.action = na.action,
         control = lmerCtr
-      ))
+      )
     } else if (use_package == "lme4") {
-      model <- do.call(getfun("lme4::lmer"), list(
+      model <- lme4::lmer(
         formula = lmerformula,
         data = data,
         na.action = na.action,
         control = lmerCtr
-      ))
+      )
     }
     return(model)
   }
@@ -250,22 +251,20 @@ lme_model <- function(data,
     }
     if (use_package == "lmerTest") {
       # run lmerTest model
-      model <- lmerTest::lmer(formula = lmerformula, data = data, na.action = na.action, control = lmerCtr)
-      # model <- do.call(getfun("lmerTest::lmer"), list(
-      #   formula = lmerformula,
-      #   data = data,
-      #   na.action = na.action,
-      #   control = lmerCtr
-      # ))
+      model <- lmerTest::lmer(
+        formula = lmerformula,
+        data = data,
+        na.action = na.action,
+        control = lmerCtr
+      )
     } else if (use_package == "lme4") {
       # run lme4 model
-      model <- lme4::lmer(formula = lmerformula, data = data, na.action = na.action, control = lmerCtr)
-      # model <- do.call(getfun("lme4::lmer"), list(
-      #   formula = lmerformula,
-      #   data = data,
-      #   na.action = na.action,
-      #   control = lmerCtr
-      # ))
+      model <- lme4::lmer(
+        formula = lmerformula,
+        data = data,
+        na.action = na.action,
+        control = lmerCtr
+      )
     }
   }
   return(model)
